Learn R Programming

hexView (version 0.3-4)

print.rawBlock: Print Method for Block of Binary Data

Description

This function displays a "rawBlock" object. Each line of output contains a binary offset, the binary data in a raw machine format, and an interpretation of the data in a human-readable format. The object contains parameters controlling the format of the display, some of which may be overridden in the call to print.

Usage

# S3 method for rawBlock
print(x, width = NULL, machine = NULL,
      sep1 = "  :  ", sep2 = "  |  ",
      showOffset = TRUE, showHuman = TRUE, 
      page = FALSE, ...)

Arguments

x

A "rawBlock" object.

width

The number of bytes to display per line of output.

machine

The machine format to display; either "hex" or "binary".

sep1

A separator to insert between the block offset and the machine format.

sep2

A separator to insert between the machine format and the human-readable format.

showOffset

If FALSE, the column of offsets is not printed.

showHuman

If FALSE, the column of human-readable format is not printed.

page

If TRUE the output is sent to the file viewer specified by getOption("pager").

…

Other arguments to print.

Details

If either width or machine is NULL, the relevant value is taken from the "rawBlock" object. The human-readable format is taken from the "rawBlock" object.

See Also

readRaw as.character.rawBlock

Examples

Run this code
# NOT RUN {
fileBlock <- readRaw(hexViewFile("rawTest.txt"))
print(fileBlock)
print(fileBlock, width=8)
print(fileBlock, machine="binary", width=4)
# }

Run the code above in your browser using DataLab